@@ -1,20 +1,9 @@
 """Permutation test function as described in CellPhoneDB 2.0."""
-# TODO: disable data-science-types because below does not generate types in shpinx + create an issue
 from __future__ import annotations
 
 from abc import ABC
 from types import MappingProxyType
-from typing import (
-    Any,
-    List,
-    Tuple,
-    Union,
-    Mapping,
-    Iterable,
-    Optional,
-    Sequence,
-    TYPE_CHECKING,
-)
+from typing import Any, Tuple, Union, Mapping, Iterable, Sequence, TYPE_CHECKING
 from functools import partial
 from itertools import product
 from collections import namedtuple
@@ -28,9 +17,10 @@ import numpy as np
 import pandas as pd
 
 from squidpy._docs import d, inject_docs
-from squidpy._utils import Signal, SigQueue, parallelize, _get_n_cores
+from squidpy._utils import Signal, NDArrayA, SigQueue, parallelize, _get_n_cores
 from squidpy.gr._utils import (
     _save_data,
+    _genesymbols,
     _assert_positive,
     _create_sparse_df,
     _check_tuple_needles,
@@ -54,13 +44,13 @@ TempResult = namedtuple("TempResult", ["means", "pvalues"])
 _template = """
 @njit(parallel={parallel}, cache=False, fastmath=False)
 def _test_{n_cls}_{ret_means}_{parallel}(
-    interactions: np.ndarray[np.uint32],
-    interaction_clusters: np.ndarray[np.uint32],
-    data: np.ndarray[np.float64],
-    clustering: np.ndarray[np.uint32],
-    mean: np.ndarray[np.float64],
-    mask: np.ndarray[np.bool_],
-    res: np.ndarray[np.float64],
+    interactions: NDArrayA,  # [np.uint32],
+    interaction_clusters: NDArrayA,  # [np.uint32],
+    data: NDArrayA,  # [np.float64],
+    clustering: NDArrayA,  # [np.uint32],
+    mean: NDArrayA,  # [np.float64],
+    mask: NDArrayA,  # [np.bool_],
+    res: NDArrayA,  # [np.float64],
     {args}
 ) -> None:
 
@@ -74,13 +64,19 @@ def _test_{n_cls}_{ret_means}_{parallel}(
             c1, c2 = interaction_clusters[j]
             m1, m2 = mean[rec, c1], mean[lig, c2]
 
+            if np.isnan(res[i, j]):
+                continue
+
             if m1 > 0 and m2 > 0:
                 {set_means}
                 if mask[rec, c1] and mask[lig, c2]:
-                    res[i, j] += (groups[c1, rec] + groups[c2, lig]) > (m1 + m2)  # division by 2 doesn't matter
+                    # both rec, lig are sufficiently expressed in c1, c2
+                    res[i, j] += (groups[c1, rec] + groups[c2, lig]) > (m1 + m2)
+                else:
+                    res[i, j] = np.nan
             else:
-                res[i, j] += np.nan
-                # res_means should be initialized all with 0s
+                # res_means is initialized with 0s
+                res[i, j] = np.nan
 """
 
 
@@ -117,7 +113,7 @@ def _create_template(n_cls: int, return_means: bool = False, parallel: bool = Tr
     finalize = f"groups = np.stack(({finalize}))"
 
     if return_means:
-        args = "res_means: np.ndarray[np.float64]"
+        args = "res_means: NDArrayA,  # [np.float64]"
         set_means = "res_means[i, j] = (m1 + m2) / 2.0"
     else:
         args = set_means = ""
@@ -134,14 +130,12 @@ def _create_template(n_cls: int, return_means: bool = False, parallel: bool = Tr
     )
 
 
-def _fdr_correct(
-    pvals: pd.DataFrame, corr_method: str, corr_axis: Union[str, CorrAxis], alpha: float = 0.05
-) -> pd.DataFrame:
+def _fdr_correct(pvals: pd.DataFrame, corr_method: str, corr_axis: str | CorrAxis, alpha: float = 0.05) -> pd.DataFrame:
     """Correct p-values for FDR along specific axis in ``pvals``."""
     from pandas.core.arrays.sparse import SparseArray
     from statsmodels.stats.multitest import multipletests
 
-    def fdr(pvals: pd.Series[np.float64]) -> SparseArray[np.float64]:
+    def fdr(pvals: pd.Series) -> SparseArray:
         _, qvals, _, _ = multipletests(
             np.nan_to_num(pvals.values, copy=True, nan=1.0),
             method=corr_method,
@@ -149,7 +143,7 @@ def _fdr_correct(
             is_sorted=False,
             returnsorted=False,
         )
-        qvals[np.isclose(qvals, 1.0)] = np.nan
+        qvals[np.isnan(pvals.values)] = np.nan
 
         return SparseArray(qvals, dtype=qvals.dtype, fill_value=np.nan)
 
@@ -205,15 +199,15 @@ class PermutationTestABC(ABC):
             csc_matrix(adata.X), index=adata.obs_names, columns=adata.var_names
         )
 
-        self._interactions: Optional[pd.DataFrame] = None
-        self._filtered_data: Optional[pd.DataFrame] = None
+        self._interactions: pd.DataFrame | None = None
+        self._filtered_data: pd.DataFrame | None = None
 
     @d.get_full_description(base="PT_prepare")
     @d.get_sections(base="PT_prepare", sections=["Parameters", "Returns"])
     @inject_docs(src=SOURCE, tgt=TARGET, cp=ComplexPolicy)
     def prepare(
-        self, interactions: Interaction_t, complex_policy: Union[str, ComplexPolicy] = ComplexPolicy.MIN.v
-    ) -> "PermutationTestABC":
+        self, interactions: Interaction_t, complex_policy: str | ComplexPolicy = ComplexPolicy.MIN.v
+    ) -> PermutationTestABC:
         """
         Prepare self for running the permutation test.
 
@@ -278,7 +272,7 @@ class PermutationTestABC(ABC):
         if self.interactions.empty:
             raise ValueError("The interactions are empty")
 
-        # first uppercaseA, then drop duplicates
+        # first uppercase, then drop duplicates
         self._data.columns = self._data.columns.str.upper()
         self.interactions[SOURCE] = self.interactions[SOURCE].str.upper()
         self.interactions[TARGET] = self.interactions[TARGET].str.upper()
@@ -308,18 +302,18 @@ class PermutationTestABC(ABC):
     def test(
         self,
         cluster_key: str,
-        clusters: Optional[Cluster_t] = None,
+        clusters: Cluster_t | None = None,
         n_perms: int = 1000,
         threshold: float = 0.01,
-        seed: Optional[int] = None,
-        corr_method: Optional[str] = None,
-        corr_axis: Union[str, CorrAxis] = CorrAxis.INTERACTIONS.v,
+        seed: int | None = None,
+        corr_method: str | None = None,
+        corr_axis: str | CorrAxis = CorrAxis.INTERACTIONS.v,
         alpha: float = 0.05,
         copy: bool = False,
-        key_added: Optional[str] = None,
-        numba_parallel: Optional[bool] = None,
+        key_added: str | None = None,
+        numba_parallel: bool | None = None,
         **kwargs: Any,
-    ) -> Optional[Mapping[str, pd.DataFrame]]:
+    ) -> Mapping[str, pd.DataFrame] | None:
         """
         Perform the permutation test as described in :cite:`cellphonedb`.
 
@@ -370,7 +364,7 @@ class PermutationTestABC(ABC):
             assert isinstance(self._filtered_data, pd.DataFrame)
 
         interactions = self.interactions[[SOURCE, TARGET]]
-        self._filtered_data["clusters"] = self._adata.obs[cluster_key].astype("string").astype("category").values
+        self._filtered_data["clusters"] = self._adata.obs.copy()[cluster_key].astype("string").astype("category").values
 
         if clusters is None:
             clusters = list(map(str, self._adata.obs[cluster_key].cat.categories))
@@ -396,7 +390,7 @@ class PermutationTestABC(ABC):
         data.columns = [gene_mapper[c] if c != "clusters" else c for c in data.columns]
         clusters_ = np.array([[cluster_mapper[c1], cluster_mapper[c2]] for c1, c2 in clusters], dtype=np.uint32)
 
-        cat.rename_categories(cluster_mapper, inplace=True)
+        data["clusters"] = cat.rename_categories(cluster_mapper)
         # much faster than applymap (tested on 1M interactions)
         interactions_ = np.vectorize(lambda g: gene_mapper[g])(interactions.values)
 
@@ -416,7 +410,6 @@ class PermutationTestABC(ABC):
             numba_parallel=numba_parallel,
             **kwargs,
         )
-
         res = {
             "means": _create_sparse_df(
                 res.means,
@@ -496,7 +489,9 @@ class PermutationTestABC(ABC):
         but no filtering happens at this stage - genes not present in the data are filtered at a later stage.
         """
 
-        def find_min_gene_in_complex(_complex: str) -> Optional[str]:
+        def find_min_gene_in_complex(_complex: str) -> str | None:
+            if "_" not in _complex:
+                return _complex
             complexes = [c for c in _complex.split("_") if c in self._data.columns]
             if not len(complexes):
                 return None
@@ -505,7 +500,7 @@ class PermutationTestABC(ABC):
 
             df = self._data[complexes].mean()
 
-            return df.index[df.argmin()]  # type: ignore[no-any-return]
+            return str(df.index[df.argmin()])
 
         if TYPE_CHECKING:
             assert isinstance(self._interactions, pd.DataFrame)
@@ -528,7 +523,7 @@ class PermutationTestABC(ABC):
             raise NotImplementedError(f"Complex policy {complex_policy!r} is not implemented.")
 
     @property
-    def interactions(self) -> Optional[pd.DataFrame]:
+    def interactions(self) -> pd.DataFrame | None:
         """The interactions."""  # noqa: D401
         return self._interactions
 
@@ -556,13 +551,13 @@ class PermutationTest(PermutationTestABC):
     @d.dedent
     def prepare(
         self,
-        interactions: Optional[Interaction_t] = None,
+        interactions: Interaction_t | None = None,
         complex_policy: str = ComplexPolicy.MIN.v,
         interactions_params: Mapping[str, Any] = MappingProxyType({}),
         transmitter_params: Mapping[str, Any] = MappingProxyType({"categories": "ligand"}),
         receiver_params: Mapping[str, Any] = MappingProxyType({"categories": "receptor"}),
         **_: Any,
-    ) -> "PermutationTest":
+    ) -> PermutationTest:
         """
         %(PT_prepare.full_desc)s
 
@@ -607,8 +602,8 @@ class PermutationTest(PermutationTestABC):
                 columns={"genesymbol_intercell_source": SOURCE, "genesymbol_intercell_target": TARGET}, inplace=True
             )
 
-            interactions[SOURCE] = interactions[SOURCE].str.lstrip("COMPLEX:")
-            interactions[TARGET] = interactions[TARGET].str.lstrip("COMPLEX:")
+            interactions[SOURCE] = interactions[SOURCE].str.replace("^COMPLEX:", "", regex=True)
+            interactions[TARGET] = interactions[TARGET].str.replace("^COMPLEX:", "", regex=True)
 
         _ = super().prepare(interactions, complex_policy=complex_policy)
         return self
@@ -618,16 +613,17 @@ class PermutationTest(PermutationTestABC):
 def ligrec(
     adata: AnnData,
     cluster_key: str,
-    interactions: Optional[Interaction_t] = None,
+    interactions: Interaction_t | None = None,
     complex_policy: str = ComplexPolicy.MIN.v,
     threshold: float = 0.01,
-    corr_method: Optional[str] = None,
+    corr_method: str | None = None,
     corr_axis: str = CorrAxis.CLUSTERS.v,
     use_raw: bool = True,
     copy: bool = False,
-    key_added: Optional[str] = None,
+    key_added: str | None = None,
+    gene_symbols: str | None = None,
     **kwargs: Any,
-) -> Optional[Mapping[str, pd.DataFrame]]:
+) -> Mapping[str, pd.DataFrame] | None:
     """
     %(PT_test.full_desc)s
 
@@ -636,36 +632,39 @@ def ligrec(
     %(PT.parameters)s
     %(PT_prepare_full.parameters)s
     %(PT_test.parameters)s
+    gene_symbols
+        Key in :attr:`anndata.AnnData.var` to use instead of :attr:`anndata.AnnData.var_names`.
 
     Returns
     -------
     %(ligrec_test_returns)s
     """  # noqa: D400
-    return (  # type: ignore[no-any-return]
-        PermutationTest(adata, use_raw=use_raw)
-        .prepare(interactions, complex_policy=complex_policy, **kwargs)
-        .test(
-            cluster_key=cluster_key,
-            threshold=threshold,
-            corr_method=corr_method,
-            corr_axis=corr_axis,
-            copy=copy,
-            key_added=key_added,
-            **kwargs,
+    with _genesymbols(adata, key=gene_symbols, use_raw=use_raw, make_unique=False):
+        return (  # type: ignore[no-any-return]
+            PermutationTest(adata, use_raw=use_raw)
+            .prepare(interactions, complex_policy=complex_policy, **kwargs)
+            .test(
+                cluster_key=cluster_key,
+                threshold=threshold,
+                corr_method=corr_method,
+                corr_axis=corr_axis,
+                copy=copy,
+                key_added=key_added,
+                **kwargs,
+            )
         )
-    )
 
 
 @d.dedent
 def _analysis(
     data: pd.DataFrame,
-    interactions: np.ndarray,
-    interaction_clusters: np.ndarray,
+    interactions: NDArrayA,
+    interaction_clusters: NDArrayA,
     threshold: float = 0.1,
     n_perms: int = 1000,
-    seed: Optional[int] = None,
+    seed: int | None = None,
     n_jobs: int = 1,
-    numba_parallel: Optional[bool] = None,
+    numba_parallel: bool | None = None,
     **kwargs: Any,
 ) -> TempResult:
     """
@@ -703,7 +702,7 @@ def _analysis(
     def extractor(res: Sequence[TempResult]) -> TempResult:
         assert len(res) == n_jobs, f"Expected to find `{n_jobs}` results, found `{len(res)}`."
 
-        meanss: List[np.ndarray] = [r.means for r in res if r.means is not None]
+        meanss: list[NDArrayA] = [r.means for r in res if r.means is not None]
         assert len(meanss) == 1, f"Only `1` job should've calculated the means, but found `{len(meanss)}`."
         means = meanss[0]
         if TYPE_CHECKING:
@@ -743,16 +742,16 @@ def _analysis(
 
 
 def _analysis_helper(
-    perms: np.ndarray,
-    data: np.ndarray,
-    mean: np.ndarray,
-    mask: np.ndarray,
-    interactions: np.ndarray,
-    interaction_clusters: np.ndarray,
-    clustering: np.ndarray,
-    seed: Optional[int] = None,
-    numba_parallel: Optional[bool] = None,
-    queue: Optional[SigQueue] = None,
+    perms: NDArrayA,
+    data: NDArrayA,
+    mean: NDArrayA,
+    mask: NDArrayA,
+    interactions: NDArrayA,
+    interaction_clusters: NDArrayA,
+    clustering: NDArrayA,
+    seed: int | None = None,
+    numba_parallel: bool | None = None,
+    queue: SigQueue | None = None,
 ) -> TempResult:
     """
     Run the results of mean, percent and shuffled analysis.
@@ -811,7 +810,7 @@ def _analysis_helper(
     _test = globals()[fn_key]
 
     if return_means:
-        res_means: Optional[np.ndarray] = np.zeros((len(interactions), len(interaction_clusters)), dtype=np.float64)
+        res_means: NDArrayA | None = np.zeros((len(interactions), len(interaction_clusters)), dtype=np.float64)
         test = partial(_test, res_means=res_means)
     else:
         res_means = None
